from setuptools import setup

setup(name='rehan_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['rehan_distributions'],
      author = 'Rehan Ahmar Sk',
      zip_safe=False)
